@@ -28,12 +28,9 @@
 #include <vorbis/vorbisenc.h>
 #include <time.h>
 #include <stdlib.h>
-#include <kconfig.h>
-#include <knuminput.h>
+#include <KConfig>
 #include <QByteArray>
 #include <QDateTime>
-#include <kglobal.h>
-#include <klocale.h>
 
 extern "C"
 {
@@ -80,9 +77,9 @@ EncoderVorbis::~EncoderVorbis(){
 
 QWidget* EncoderVorbis::getConfigureWidget(KConfigSkeleton** manager) const {
   (*manager) = Settings::self();
-  KGlobal::locale()->insertCatalog( QLatin1String( "audiocd_encoder_vorbis" ));
   EncoderVorbisConfig *config = new EncoderVorbisConfig();
-  config->kcfg_vorbis_quality->setRange(0.0, 10.0, 0.2, true);
+  config->kcfg_vorbis_quality->setRange(0.0, 10.0);
+  config->kcfg_vorbis_quality->setSingleStep(0.1);
   config->vorbis_bitrate_settings->hide();
   return config;
 }
@@ -214,8 +211,8 @@ long EncoderVorbis::readInit(long /*size*/){
   vorbis_analysis_init(&d->vd,&d->vi);
   vorbis_block_init(&d->vd,&d->vb);
 
-  srand(time(NULL));
-  ogg_stream_init(&d->os,rand());
+  qsrand(time(NULL));
+  ogg_stream_init(&d->os,qrand());
 
   vorbis_analysis_headerout(&d->vd,&d->vc,&header,&header_comm,&header_code);
 
@@ -241,7 +238,7 @@ long EncoderVorbis::readInit(long /*size*/){
   return 0;
 }
 
-long EncoderVorbis::read(int16_t * buf, int frames){
+long EncoderVorbis::read(qint16 * buf, int frames){
   int i;
   float **buffer=vorbis_analysis_buffer(&d->vd,frames);
 
